# dividere
Distributed Systems Framework

Dīvidere, latin for "to divide, to seperate" seemed an appropriate package name for a distributed system framework project.  

The primary goal of dīvidere is to combine three complementary technologies (Python, ZeroMQ, Protobuf) into a distributed system messaging framework.  ZeroMQ will provide a variety of transport mechanisms, Protobuf providing a language-independent, strongly-typed message encoding and Python the means to combine these components into a reusable framework.

Refer to the user guide:
<a href="https://github.com/lipeltgm/dividere/blob/main/main.pdf" target="_blank">User Guide</a>

